;; Generated package description from plz-event-source.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "plz-event-source" "0.1.4pre0.20250413.0" "Plz Event Source" '((emacs "26.3") (plz-media-type "0.2.4")) :commit "de89214ce14e2b82cbfdc30e1adcf3e77b1f250a" :authors '(("r0man" . "roman@burningswell.com")) :maintainer '("r0man" . "roman@burningswell.com") :keywords '("comm" "network" "http") :url "https://github.com/r0man/plz-event-source")
